/*
 * more complex example of incorrect function graph generation.
 * 
 * if the opening parenthesis of a function is on a separate line from the function's name, the
 * function is apparently not recognised as a new function definition, but becomes an invocation from a
 * previous function.
 *
 */

int main_example_3broken (int argc, char *argv[]);
int subfunc0_3broken (int argc, char *argv);    /* only invoked from main */
int subfunc1_3broken (int argc);                /* only invoked from main */
int subfunc2_3broken (int argc);                /* not invoked from within this file */
int subfunc3_3broken (int argc);                /* also invoked from subfunc1  */

/**
 * \brief the main part of the example; invokes subfuncs 0,1, and 3 directly;
 *  direct invocations charted correctly; does NOT invoke subfunc2; 
 * \param argc number of arguments in the arg vector
 * \param argv pointer to an array of strings containing the command line arguments
 */

int main_example_3broken
(
    int argc,
    char *argv[]
)
{
    int result;
    result = subfunc0_3broken (argc, argv[0]);
    result = subfunc1_3broken (argc);
    result = subfunc3_3broken (argc);
}

/**
 * \brief a function invoked by main only; invokes no other subfunc;
 *  charts incorrectly as invoking subfunc1_3broken()
 * \param argc number of arguments in the arg vector
 * \param arg pointer to one string from the command line
 */
int subfunc0_3broken
(
    int argc,
    char *arg
)
{
    (void) argc;
    (void) arg;
    return 0;
}

/**
 * \brief another function invoked by main only; invokes only subfunc3_3broken;
 *  charts incorrectly as invoked from subfunc0_3broken()
 *  and incorrectly as invoking subfunc2_3broken()
 * \param argc number of arguments in the arg vector
 */
int subfunc1_3broken
(
    int argc
)
{
    (void) argc;
    return subfunc3_3broken (1);
}

/**
 * \brief a second function; not invoked by any function in this example; invokes no other subfunc;
 *  charts incorrectly as invoked from subfunc1_3broken()
 *  and incorrectly as invoking subfunc3_3broken()
 * \param argc number of arguments in the arg vector
 */
int subfunc2_3broken
(
    int argc
)
{
    (void) argc;
    return 2;
}

/**
 * \brief a third function; invoked by main and subfunc1_3broken; invokes no other subfunc;
 *  charts incorrectly as invoked from subfunc2_3broken()
 * \param argc number of arguments in the arg vector
 */
int subfunc3_3broken
(
    int argc
)
{
    (void) argc;
    return 3;
}
